@@ -138,9 +138,17 @@ namespace vsgXchange
         int printAssimp = 0;
         bool externalTextures = false;
         TextureFormat externalTextureFormat = TextureFormat::native;
-        bool sRGBTextures = false;
         bool culling = true;
 
+        // set for the file format being read.
+        vsg::CoordinateSpace sourceVertexColorSpace = vsg::CoordinateSpace::LINEAR;
+        vsg::CoordinateSpace sourceMaterialColorSpace = vsg::CoordinateSpace::LINEAR;
+
+        // set for the target ShaderSet's
+        vsg::CoordinateSpace targetVertexColorSpace = vsg::CoordinateSpace::LINEAR;
+        vsg::CoordinateSpace targetMaterialCoordinateSpace = vsg::CoordinateSpace::LINEAR;
+
+
         // TODO flatShadedShaderSet?
         vsg::ref_ptr<vsg::ShaderSet> pbrShaderSet;
         vsg::ref_ptr<vsg::ShaderSet> phongShaderSet;
@@ -162,27 +170,29 @@ namespace vsgXchange
         SubgraphStats print(std::ostream& out, const aiNode* in_node, vsg::indentation indent);
         SubgraphStats print(std::ostream& out, const aiScene* in_scene, vsg::indentation indent);
 
-        static vsg::vec3 convert(const aiVector3D& v) { return vsg::vec3(v[0], v[1], v[2]); }
-        static vsg::dvec3 dconvert(const aiVector3D& v) { return vsg::dvec3(v[0], v[1], v[2]); }
-        static vsg::vec3 convert(const aiColor3D& v) { return vsg::vec3(v[0], v[1], v[2]); }
-        static vsg::vec4 convert(const aiColor4D& v) { return vsg::vec4(v[0], v[1], v[2], v[3]); }
+        vsg::vec3 convert(const aiVector3D& v) { return vsg::vec3(v[0], v[1], v[2]); }
+        vsg::dvec3 dconvert(const aiVector3D& v) { return vsg::dvec3(v[0], v[1], v[2]); }
+        vsg::vec3 convert(const aiColor3D& v) { return vsg::vec3(v[0], v[1], v[2]); }
+        vsg::vec4 convert(const aiColor4D& v) { return vsg::vec4(v[0], v[1], v[2], v[3]); }
 
-        static bool getColor(const aiMaterial* material, const char* pKey, unsigned int type, unsigned int idx, vsg::vec3& value)
+        bool getColor(const aiMaterial* material, const char* pKey, unsigned int type, unsigned int idx, vsg::vec3& value)
         {
             aiColor3D color;
             if (material->Get(pKey, type, idx, color) == AI_SUCCESS)
             {
                 value = convert(color);
+                vsg::convert(value, sourceMaterialColorSpace, targetMaterialCoordinateSpace);
                 return true;
             }
             return false;
         }
-        static bool getColor(const aiMaterial* material, const char* pKey, unsigned int type, unsigned int idx, vsg::vec4& value)
+        bool getColor(const aiMaterial* material, const char* pKey, unsigned int type, unsigned int idx, vsg::vec4& value)
         {
             aiColor4D color;
             if (material->Get(pKey, type, idx, color) == AI_SUCCESS)
             {
                 value = convert(color);
+                vsg::convert(value, sourceMaterialColorSpace, targetMaterialCoordinateSpace);
                 return true;
             }
             return false;
